@@ -6,4 +6,4 @@ class CategoryAdmin(admin.ModelAdmin):
     """
     Define Work Log category
     """
-    list_display=('category',)
\ No newline at end of file
+    list_display=('category', 'category_label')
\ No newline at end of file
