@@ -31,7 +31,7 @@ class VMWorkLogViewSet(ModelViewSet):
     filterset_class = filters.VMWorkLogFilterSet
     
     def create(self, request, *args, **kwargs):
-        data = request.POST
+        data = request.data
         serializer = self.get_serializer(data=data)
         
         if serializer.is_valid():
@@ -50,7 +50,7 @@ class DeviceWorkLogViewSet(ModelViewSet):
     filterset_class = filters.DeviceWorkLogFilterSet
     
     def create(self, request, *args, **kwargs):
-        data = request.POST
+        data = request.data
         serializer = self.get_serializer(data=data)
         
         if serializer.is_valid():
